@@ -1,21 +1,26 @@
+from typing import TYPE_CHECKING
+
 from dvc.scheme import Schemes
 
+if TYPE_CHECKING:
+    from .index import ObjectDBIndexBase
+
 
 def get_odb(fs, path_info, **config):
     from .base import ObjectDB
     from .gdrive import GDriveObjectDB
     from .local import LocalObjectDB
-    from .ssh import SSHObjectDB
+    from .oss import OSSObjectDB
 
     if fs.scheme == Schemes.LOCAL:
         return LocalObjectDB(fs, path_info, **config)
 
-    if fs.scheme == Schemes.SSH:
-        return SSHObjectDB(fs, path_info, **config)
-
     if fs.scheme == Schemes.GDRIVE:
         return GDriveObjectDB(fs, path_info, **config)
 
+    if fs.scheme == Schemes.OSS:
+        return OSSObjectDB(fs, path_info, **config)
+
     return ObjectDB(fs, path_info, **config)
 
 
@@ -26,9 +31,23 @@ def _get_odb(repo, settings):
         return None
 
     cls, config, path_info = get_cloud_fs(repo, **settings)
+    config["tmp_dir"] = repo.tmp_dir
     return get_odb(cls(**config), path_info, state=repo.state, **config)
 
 
+def get_index(odb) -> "ObjectDBIndexBase":
+    import hashlib
+
+    from .index import ObjectDBIndex, ObjectDBIndexNoop
+
+    cls = ObjectDBIndex if odb.tmp_dir else ObjectDBIndexNoop
+    return cls(
+        odb.tmp_dir,
+        hashlib.sha256(odb.path_info.url.encode("utf-8")).hexdigest(),
+        odb.fs.CHECKSUM_DIR_SUFFIX,
+    )
+
+
 class ODBManager:
     CACHE_DIR = "cache"
     CLOUD_SCHEMES = [
